/* statedata2.do =generates variables for state, sample 2000-2006 */

global MY_OUT_PATH "U:\Dokumente\uni\projects\state\revision\data\"
log using "${MY_OUT_PATH}statedata2.log", text replace 

/* general remark: "missing values don't exist" means that missing values don't exist for individuals that are present in a particular wave; there may still be missing values due to non-presence in that wave */ 

set mem 100m
set more off


/* load statedata1.dta */

use "${MY_OUT_PATH}statedata1", clear


/* individual level variables */

/* employment status, missing value -> 0 */

gen byte em0 = (qp10==1 | qp10==2)
gen byte em1 = (rp12==1 | rp12==2)
gen byte em2 = (sp15==1 | sp15==2)
gen byte em3 = (tp34==1 | tp34==2)
gen byte em4 = (up09==1 | up09==2)
gen byte em5 = (vp10==1 | vp10==2)
gen byte em6 = (wp07==1 | wp07==2)


/* lagged employment status */

gen byte eml1 = em0
gen byte eml2 = em1
gen byte eml3 = em2
gen byte eml4 = em3
gen byte eml5 = em4
gen byte eml6 = em5


/* married + living together, missing value -> 0 */

gen byte marl0 = (qp140==1)
gen byte marl1 = (rp131==1)
gen byte marl2 = (sp131==1)
gen byte marl3 = (tp138==1)
gen byte marl4 = (up140==1)
gen byte marl5 = (vp148==1)
gen byte marl6 = (wp125==1)


/* not married but partner lives in household, missing value -> 0 */

gen byte unml0 = (qp14102==1)
gen byte unml1 = (rp13202==1)
gen byte unml2 = (sp13202==1)
gen byte unml3 = (tp13902==1)
gen byte unml4 = (up14102==1)
gen byte unml5 = (vp14902==1)
gen byte unml6 = (wp12602==1)


/* disability status, missing value -> 0 */

gen byte dis0 = (qp9701==1)
gen byte dis1 = (rp9701==1)
gen byte dis2 = (sp9501==1)
gen byte dis3 = (tp9901==1)
gen byte dis4 = (up9201==1)
gen byte dis5 = (vp10501==1)
gen byte dis6 = (wp9601==1)


/* university, missing value -> 0 */

gen byte uni0 = (qpbbil02==1 | qpbbil02==2 | qpbbil02==3 | qpbbil02==4 | qpbbil02==5 )
gen byte uni1 = (rpbbil02==1 | rpbbil02==2 | rpbbil02==3 | rpbbil02==4 | rpbbil02==5 )
gen byte uni2 = (spbbil02==1 | spbbil02==2 | spbbil02==3 | spbbil02==4 | spbbil02==5 )
gen byte uni3 = (tpbbil02==1 | tpbbil02==2 | tpbbil02==3 | tpbbil02==4 | tpbbil02==5 )
gen byte uni4 = (upbbil02==1 | upbbil02==2 | upbbil02==3 | upbbil02==4 | upbbil02==5 )
gen byte uni5 = (vpbbil02==1 | vpbbil02==2 | vpbbil02==3 | vpbbil02==4 | vpbbil02==5 )
gen byte uni6 = (wpbbil02==1 | wpbbil02==2 | wpbbil02==3 | wpbbil02==4 | wpbbil02==5 )


/* Abitur/Lehre, missing value -> 0, university==1 -> 0 */

gen byte abv0 = (qpsbil==3  | qpsbil==4) | (qpbbil01==1 | qpbbil01==2 | qpbbil01==3 | qpbbil01==4 | qpbbil01==5 | qpbbil01==6 )
gen byte abv1 = (rpsbil==3  | rpsbil==4) | (rpbbil01==1 | rpbbil01==2 | rpbbil01==3 | rpbbil01==4 | rpbbil01==5 | rpbbil01==6 )
gen byte abv2 = (spsbil==3  | spsbil==4) | (spbbil01==1 | spbbil01==2 | spbbil01==3 | spbbil01==4 | spbbil01==5 | spbbil01==6 )
gen byte abv3 = (tpsbil==3  | tpsbil==4) | (tpbbil01==1 | tpbbil01==2 | tpbbil01==3 | tpbbil01==4 | tpbbil01==5 | tpbbil01==6 )
gen byte abv4 = (upsbil==3  | upsbil==4) | (upbbil01==1 | upbbil01==2 | upbbil01==3 | upbbil01==4 | upbbil01==5 | upbbil01==6 )
gen byte abv5 = (vpsbil==3  | vpsbil==4) | (vpbbil01==1 | vpbbil01==2 | vpbbil01==3 | vpbbil01==4 | vpbbil01==5 | vpbbil01==6 )
gen byte abv6 = (wpsbil==3  | wpsbil==4) | (wpbbil01==1 | wpbbil01==2 | wpbbil01==3 | wpbbil01==4 | wpbbil01==5 | wpbbil01==6 )

replace abv0 = 0 if uni0==1
replace abv1 = 0 if uni1==1
replace abv2 = 0 if uni2==1
replace abv3 = 0 if uni3==1
replace abv4 = 0 if uni4==1
replace abv5 = 0 if uni5==1
replace abv6 = 0 if uni6==1


/* education, missing value -> 9 years */

gen educ0 = qbilzeit
gen educ1 = rbilzeit
gen educ2 = sbilzeit
gen educ3 = tbilzeit
gen educ4 = ubilzeit
gen educ5 = vbilzeit
gen educ6 = wbilzeit

replace educ0 = 9 if educ0 < 0 | educ0==.
replace educ1 = 9 if educ1 < 0 | educ1==.
replace educ2 = 9 if educ2 < 0 | educ2==.
replace educ3 = 9 if educ3 < 0 | educ3==.
replace educ4 = 9 if educ4 < 0 | educ4==.
replace educ5 = 9 if educ5 < 0 | educ5==.
replace educ6 = 9 if educ6 < 0 | educ6==.

gen educsq0 = educ0*educ0
gen educsq1 = educ1*educ1
gen educsq2 = educ2*educ2
gen educsq3 = educ3*educ3
gen educsq4 = educ4*educ4
gen educsq5 = educ5*educ5
gen educsq6 = educ6*educ6


/* foreigner, missing value -> German */

gen byte for0 = 1 - (nation00==1 | nation00<0 | nation00==.)
gen byte for1 = 1 - (nation01==1 | nation01<0 | nation01==.)
gen byte for2 = 1 - (nation02==1 | nation02<0 | nation02==.)
gen byte for3 = 1 - (nation03==1 | nation03<0 | nation03==.)
gen byte for4 = 1 - (nation04==1 | nation04<0 | nation04==.)
gen byte for5 = 1 - (nation05==1 | nation05<0 | nation05==.)
gen byte for6 = 1 - (nation06==1 | nation06<0 | nation06==.)


/* age & age categories, drop missing values */

drop if gebjahr < 0 | gebjahr ==.

gen age0 = 2000 - gebjahr
gen age1 = 2001 - gebjahr
gen age2 = 2002 - gebjahr
gen age3 = 2003 - gebjahr
gen age4 = 2004 - gebjahr
gen age5 = 2005 - gebjahr
gen age6 = 2006 - gebjahr

gen agesq0 = age0*age0
gen agesq1 = age1*age1
gen agesq2 = age2*age2
gen agesq3 = age3*age3
gen agesq4 = age4*age4
gen agesq5 = age5*age5
gen agesq6 = age6*age6

forvalues i = 0/6 {

  gen age26t`i' = (26 <= age`i' & age`i' <= 35)
  gen age36t`i' = (36 <= age`i' & age`i' <= 45)
  gen age46t`i' = (46 <= age`i' & age`i' <= 55)
  gen age56t`i' = (56 <= age`i' & age`i' <= 65)

}

/* Bundeslaender, missing value -> 0 */

gen byte nord0 = (qbula==1 | qbula==2 | qbula==3 | qbula==4)
gen byte west0 = (qbula==5)
gen byte middle0 = (qbula==6 | qbula==7)
gen byte south0 = (qbula==8 | qbula==9)
gen byte berlin0 = (qbula==0 | qbula==11)
gen byte east0 = (qbula==12 | qbula==13 | qbula==14 | qbula==15 | qbula==16)

gen byte e0 = berlin0 | east0
gen byte w0 = 1 - e0


gen byte nord1 = (rbula==1 | rbula==2 | rbula==3 | rbula==4)
gen byte west1 = (rbula==5)
gen byte middle1 = (rbula==6 | rbula==7)
gen byte south1 = (rbula==8 | rbula==9)
gen byte berlin1 = (rbula==0 | rbula==11)
gen byte east1 = (rbula==12 | rbula==13 | rbula==14 | rbula==15 | rbula==16)

gen byte e1 = berlin1 | east1
gen byte w1 = 1 - e1


gen byte nord2 = (sbula==1 | sbula==2 | sbula==3 | sbula==4)
gen byte west2 = (sbula==5)
gen byte middle2 = (sbula==6 | sbula==7)
gen byte south2 = (sbula==8 | sbula==9)
gen byte berlin2 = (sbula==0 | sbula==11)
gen byte east2 = (sbula==12 | sbula==13 | sbula==14 | sbula==15 | sbula==16)

gen byte e2 = berlin2 | east2
gen byte w2 = 1 - e2


gen byte nord3 = (tbula==1 | tbula==2 | tbula==3 | tbula==4)
gen byte west3 = (tbula==5)
gen byte middle3 = (tbula==6 | tbula==7)
gen byte south3 = (tbula==8 | tbula==9)
gen byte berlin3 = (tbula==0 | tbula==11)
gen byte east3 = (tbula==12 | tbula==13 | tbula==14 | tbula==15 | tbula==16)

gen byte e3 = berlin3 | east3
gen byte w3 = 1 - e3


gen byte nord4 = (ubula==1 | ubula==2 | ubula==3 | ubula==4)
gen byte west4 = (ubula==5)
gen byte middle4 = (ubula==6 | ubula==7)
gen byte south4 = (ubula==8 | ubula==9)
gen byte berlin4 = (ubula==0 | ubula==11)
gen byte east4 = (ubula==12 | ubula==13 | ubula==14 | ubula==15 | ubula==16)

gen byte e4 = berlin4 | east4
gen byte w4 = 1 - e4


gen byte nord5 = (vbula==1 | vbula==2 | vbula==3 | vbula==4)
gen byte west5 = (vbula==5)
gen byte middle5 = (vbula==6 | vbula==7)
gen byte south5 = (vbula==8 | vbula==9)
gen byte berlin5 = (vbula==0 | vbula==11)
gen byte east5 = (vbula==12 | vbula==13 | vbula==14 | vbula==15 | vbula==16)

gen byte e5 = berlin5 | east5
gen byte w5 = 1 - e5


gen byte nord6 = (vbula==1 | vbula==2 | vbula==3 | vbula==4)
gen byte west6 = (vbula==5)
gen byte middle6 = (vbula==6 | vbula==7)
gen byte south6 = (vbula==8 | vbula==9)
gen byte berlin6 = (vbula==0 | vbula==11)
gen byte east6 = (vbula==12 | vbula==13 | vbula==14 | vbula==15 | vbula==16)

gen byte e6 = berlin6 | east6
gen byte w6 = 1 - e6


/* longitudinal weight, missing values don't exist; THESE WEIGHTS COVER 2000 TO 2006 */

gen lweight = qphrf * rpbleib * spbleib * tpbleib * upbleib * vpbleib * wpbleib


/* household level variables */

/* replace missing values in household identifier with . */

replace qhhnr = . if qhhnr<0
replace rhhnr = . if rhhnr<0
replace shhnr = . if shhnr<0
replace thhnr = . if thhnr<0
replace uhhnr = . if uhhnr<0
replace vhhnr = . if vhhnr<0
replace whhnr = . if whhnr<0


/* replace missing values in household income with . */
  
replace qh54 = . if qh54<0    
replace rh49 = . if rh49<0    
replace sh4901 = . if sh4901<0
replace th4801 = . if th4801<0
replace uh4801 = . if uh4801<0
replace vh5101 = . if vh5101<0
replace wh5101 = . if wh5101<0


/* equivalent income, only for non-missing values in income, no missing values in household size if income non-missing */
 
gen eq0 = qh54/sqrt(qhhgr) if qh54!=.    
gen eq1 = rh49/sqrt(rhhgr) if rh49!=.    
gen eq2 = sh4901/sqrt(shhgr) if sh4901!=. 
gen eq3 = th4801/sqrt(thhgr) if th4801!=. 
gen eq4 = uh4801/sqrt(uhhgr) if uh4801!=. 
gen eq5 = vh5101/sqrt(vhhgr) if vh5101!=.
gen eq6 = wh5101/sqrt(whhgr) if wh5101!=.


/* poverty status, only non-missing income values, poverty line = 60/50/70 percent of median */

forvalues i=0/6 {

  if `i'==0 qreg eq0 [weight=qphrf]
  if `i'==1 qreg eq1 [weight=rphrf]
  if `i'==2 qreg eq2 [weight=sphrf]
  if `i'==3 qreg eq3 [weight=tphrf]
  if `i'==4 qreg eq4 [weight=uphrf]
  if `i'==5 qreg eq5 [weight=vphrf]
  if `i'==6 qreg eq6 [weight=wphrf]
  
  matrix me=e(b)
  gen byte p`i' = (eq`i' < 0.6 * me[1,1]) if eq`i'!=.
  gen byte p05t`i' = (eq`i' < 0.5 * me[1,1]) if eq`i'!=.
  gen byte p07t`i' = (eq`i' < 0.7 * me[1,1]) if eq`i'!=.

}

/* poverty rates, automatically only for non-missing income values */
   
version 7: svymean p0 p05t0 p07t0 [pweight=qphrf]
version 7: svymean p1 p05t1 p07t1 [pweight=rphrf]
version 7: svymean p2 p05t2 p07t2 [pweight=sphrf]
version 7: svymean p3 p05t3 p07t3 [pweight=tphrf]  
version 7: svymean p4 p05t4 p07t4 [pweight=uphrf]       
version 7: svymean p5 p05t5 p07t5 [pweight=vphrf] 
version 7: svymean p6 p05t6 p07t6 [pweight=wphrf]                 
                   

/* lagged poverty status */

gen byte pl1 = p0
gen byte pl2 = p1
gen byte pl3 = p2
gen byte pl4 = p3
gen byte pl5 = p4
gen byte pl6 = p5

gen byte p05lt1 = p05t0
gen byte p05lt2 = p05t1
gen byte p05lt3 = p05t2
gen byte p05lt4 = p05t3
gen byte p05lt5 = p05t4
gen byte p05lt6 = p05t5

gen byte p07lt1 = p07t0
gen byte p07lt2 = p07t1
gen byte p07lt3 = p07t2
gen byte p07lt4 = p07t3
gen byte p07lt5 = p07t4
gen byte p07lt6 = p07t5


/* living with others dummy, only for non-missing values of household size (missing values of household size can only be due to non-presence in given wave) */

gen byte lwo0 = (qhhgr>1) if qhhgr!=.
gen byte lwo1 = (rhhgr>1) if rhhgr!=.
gen byte lwo2 = (shhgr>1) if shhgr!=.
gen byte lwo3 = (thhgr>1) if thhgr!=.
gen byte lwo4 = (uhhgr>1) if uhhgr!=.
gen byte lwo5 = (vhhgr>1) if vhhgr!=.
gen byte lwo6 = (whhgr>1) if whhgr!=.


/* lagged living with others dummy */

gen byte lwol1 = lwo0
gen byte lwol2 = lwo1
gen byte lwol3 = lwo2
gen byte lwol4 = lwo3
gen byte lwol5 = lwo4
gen byte lwol6 = lwo5


/* number of children in household, generated from data */

egen hch0 = sum(0 <= age0 & age0 <= 17) if qhhnr!=., by(qhhnr)
egen hch1 = sum(0 <= age1 & age1 <= 17) if rhhnr!=., by(rhhnr)
egen hch2 = sum(0 <= age2 & age2 <= 17) if shhnr!=., by(shhnr)
egen hch3 = sum(0 <= age3 & age3 <= 17) if thhnr!=., by(thhnr)
egen hch4 = sum(0 <= age4 & age4 <= 17) if uhhnr!=., by(uhhnr)
egen hch5 = sum(0 <= age5 & age5 <= 17) if vhhnr!=., by(vhhnr)
egen hch6 = sum(0 <= age6 & age6 <= 17) if whhnr!=., by(whhnr)


/* number of employed adults in household, generated from data */

egen hade0 = sum(18 <= age0 & em0==1) if qhhnr!=., by(qhhnr)
egen hade1 = sum(18 <= age1 & em1==1) if rhhnr!=., by(rhhnr)
egen hade2 = sum(18 <= age2 & em2==1) if shhnr!=., by(shhnr)
egen hade3 = sum(18 <= age3 & em3==1) if thhnr!=., by(thhnr)
egen hade4 = sum(18 <= age4 & em4==1) if uhhnr!=., by(uhhnr)
egen hade5 = sum(18 <= age5 & em5==1) if vhhnr!=., by(vhhnr)
egen hade6 = sum(18 <= age6 & em6==1) if whhnr!=., by(whhnr)


/* number of non-employed adults in household, generated from data */

egen hadn0 = sum(18 <= age0 & em0==0) if qhhnr!=., by(qhhnr)
egen hadn1 = sum(18 <= age1 & em1==0) if rhhnr!=., by(rhhnr)
egen hadn2 = sum(18 <= age2 & em2==0) if shhnr!=., by(shhnr)
egen hadn3 = sum(18 <= age3 & em3==0) if thhnr!=., by(thhnr)
egen hadn4 = sum(18 <= age4 & em4==0) if uhhnr!=., by(uhhnr)
egen hadn5 = sum(18 <= age5 & em5==0) if vhhnr!=., by(vhhnr)
egen hadn6 = sum(18 <= age6 & em6==0) if whhnr!=., by(whhnr)                                                


/* household size as in data (=potentially wrong) */

egen hsizdata0 = sum(1) if qhhnr!=., by(qhhnr)
egen hsizdata1 = sum(1) if rhhnr!=., by(rhhnr)
egen hsizdata2 = sum(1) if shhnr!=., by(shhnr)
egen hsizdata3 = sum(1) if thhnr!=., by(thhnr)
egen hsizdata4 = sum(1) if uhhnr!=., by(uhhnr)
egen hsizdata5 = sum(1) if vhhnr!=., by(vhhnr)
egen hsizdata6 = sum(1) if whhnr!=., by(whhnr)


/* check correctness of household size and generated variables */

count if hsizdata0 != qhhgr
count if hsizdata1 != rhhgr
count if hsizdata2 != shhgr
count if hsizdata3 != thhgr
count if hsizdata4 != uhhgr
count if hsizdata5 != vhhgr
count if hsizdata6 != whhgr

count if hsizdata0 != hch0 + hade0 + hadn0
count if hsizdata1 != hch1 + hade1 + hadn1
count if hsizdata2 != hch2 + hade2 + hadn2
count if hsizdata3 != hch3 + hade3 + hadn3
count if hsizdata4 != hch4 + hade4 + hadn4
count if hsizdata5 != hch5 + hade5 + hadn5
count if hsizdata6 != hch6 + hade6 + hadn6
  

/* generate share of men in particular age group (and unconditional) living together with others */

forvalues i = 0/6 {

  gen lwow`i' = .
  gen lwow2665`i' = .   
  gen lwow2655`i' = .

  if `i'==0 svyset [pweight=qphrf]
  if `i'==1 svyset [pweight=rphrf]
  if `i'==2 svyset [pweight=sphrf]
  if `i'==3 svyset [pweight=tphrf]
  if `i'==4 svyset [pweight=uphrf]
  if `i'==5 svyset [pweight=vphrf]
  if `i'==6 svyset [pweight=wphrf]
  
  display "year = " `i'
  
  display "26 - 35"
  svy: mean lwo`i', subpop(if 26<=age`i' & age`i'<=35 & sex==1)
  mat e = e(b)
  replace lwow`i' = e[1,1] if 26<=age`i' & age`i'<=35 & sex==1
  
  display "36 - 45"
  svy: mean lwo`i', subpop(if 36<=age`i' & age`i'<=45 & sex==1)
  mat e = e(b)
  replace lwow`i' = e[1,1] if 36<=age`i' & age`i'<=45 & sex==1
  
  display "46 - 55"
  svy: mean lwo`i', subpop(if 46<=age`i' & age`i'<=55 & sex==1)
  mat e = e(b)
  replace lwow`i' = e[1,1] if 46<=age`i' & age`i'<=55 & sex==1
  
  display "56 - 65"
  svy: mean lwo`i', subpop(if 56<=age`i' & age`i'<=65 & sex==1)
  mat e = e(b)
  replace lwow`i' = e[1,1] if 56<=age`i' & age`i'<=65 & sex==1 
  
  display "26 - 65"                                            
  svy: mean lwo`i', subpop(if 26<=age`i' & age`i'<=65 & sex==1)
  mat e = e(b)                                                 
  replace lwow2665`i' = e[1,1] if 26<=age`i' & age`i'<=65 & sex==1
  
  display "26 - 55"                                            
  svy: mean lwo`i', subpop(if 26<=age`i' & age`i'<=55 & sex==1)
  mat e = e(b)                                                 
  replace lwow2655`i' = e[1,1] if 26<=age`i' & age`i'<=55 & sex==1 

} 
  

/* merge unemployment rate of Bundesland (West Berlin and East Berlin (=11) -> bula = 0) */

gen bula = .

replace bula = qbula
replace bula = 0 if bula==11
sort bula
merge bula using "${MY_OUT_PATH}alqwide", keep(alq0)
tab _merge
drop if _merge==2
drop _merge

replace bula = rbula
replace bula = 0 if bula==11
sort bula
merge bula using "${MY_OUT_PATH}alqwide", keep(alq1)
tab _merge
drop if _merge==2
drop _merge

replace bula = sbula
replace bula = 0 if bula==11
sort bula
merge bula using "${MY_OUT_PATH}alqwide", keep(alq2)
tab _merge
drop if _merge==2
drop _merge

replace bula = tbula
replace bula = 0 if bula==11
sort bula
merge bula using "${MY_OUT_PATH}alqwide", keep(alq3)
tab _merge
drop if _merge==2
drop _merge

replace bula = ubula
replace bula = 0 if bula==11
sort bula
merge bula using "${MY_OUT_PATH}alqwide", keep(alq4)
tab _merge
drop if _merge==2
drop _merge

replace bula = vbula
replace bula = 0 if bula==11
sort bula
merge bula using "${MY_OUT_PATH}alqwide", keep(alq5)
tab _merge
drop if _merge==2
drop _merge

replace bula = wbula
replace bula = 0 if bula==11
sort bula
merge bula using "${MY_OUT_PATH}alqwide", keep(alq6)
tab _merge
drop if _merge==2
drop _merge

drop bula


/* save sample prior to selection */

sort persnr

label data "statedata2prior"
save  "${MY_OUT_PATH}statedata2prior", replace
desc
sum


/* sample selection */

/* valid income information in every wave 2000 - 2006 */

drop if qh54==. | qh54<0
drop if rh49==. | rh49<0
drop if sh4901==. | sh4901<0
drop if th4801==. | th4801<0
drop if uh4801==. | uh4801<0
drop if vh5101==. | vh5101<0
drop if wh5101==. | wh5101<0


/* keep only men */

keep if sex == 1


/* drop individuals out of age range */

keep if 26 <= age0 & age6 <= 65


/* balanced sample; ONLY 2000 - 2006 */

keep if ( ( qnetto > 0 & qnetto < 40 ) & ( rnetto > 0 & rnetto < 40 ) & ( snetto > 0 & snetto < 40 ) & ( tnetto > 0 & tnetto < 40 ) & ( unetto > 0 & unetto < 40 ) & ( vnetto > 0 & vnetto < 40 ) & ( wnetto > 0 & wnetto < 40 ))


/* generate time averages; ONLY 2001 - 2006 */

egen pa = rowmean(p1 p2 p3 p4 p5 p6)
egen eqa = rowmean(eq1 eq2 eq3 eq4 eq5 eq6)
egen ema = rowmean(em1 em2 em3 em4 em5 em6)
egen marla = rowmean(marl1 marl2 marl3 marl4 marl5 marl6)
egen unmla = rowmean(unml1 unml2 unml3 unml4 unml5 unml6)
egen lwoa = rowmean(lwo1 lwo2 lwo3 lwo4 lwo5 lwo6)
egen disa = rowmean(dis1 dis2 dis3 dis4 dis5 dis6)
egen abva = rowmean(abv1 abv2 abv3 abv4 abv5 abv6)
egen unia = rowmean(uni1 uni2 uni3 uni4 uni5 uni6)
egen educa = rowmean(educ1 educ2 educ3 educ4 educ5 educ6) 
egen educsqa = rowmean(educsq1 educsq2 educsq3 educsq4 educsq5 educsq6)
egen fora = rowmean(for1 for2 for3 for4 for5 for6)
egen agea = rowmean(age1 age2 age3 age4 age5 age6)
egen agesqa = rowmean(agesq1 agesq2 agesq3 agesq4 agesq5 agesq6)
egen age26a = rowmean(age26t1 age26t2 age26t3 age26t4 age26t5 age26t6)
egen age36a = rowmean(age36t1 age36t2 age36t3 age36t4 age36t5 age36t6)
egen age46a = rowmean(age46t1 age46t2 age46t3 age46t4 age46t5 age46t6)
egen age56a = rowmean(age56t1 age56t2 age56t3 age56t4 age56t5 age56t6)
egen alqa = rowmean(alq1 alq2 alq3 alq4 alq5 alq6)
egen lwowa = rowmean(lwow1 lwow2 lwow3 lwow4 lwow5 lwow6)
egen norda = rowmean(nord1 nord2 nord3 nord4 nord5 nord6)
egen westa = rowmean(west1 west2 west3 west4 west5 west6)
egen middlea = rowmean(middle1 middle2 middle3 middle4 middle5 middle6)
egen southa = rowmean(south1 south2 south3 south4 south5 south6)
egen berlina = rowmean(berlin1 berlin2 berlin3 berlin4 berlin5 berlin6)
egen easta = rowmean(east1 east2 east3 east4 east5 east6)
egen ea = rowmean(e1 e2 e3 e4 e5 e6)
egen wa = rowmean(w1 w2 w3 w4 w5 w6)
egen hcha = rowmean(hch1 hch2 hch3 hch4 hch5 hch6)
egen hadea = rowmean(hade1 hade2 hade3 hade4 hade5 hade6)
egen hadna = rowmean(hadn1 hadn2 hadn3 hadn4 hadn5 hadn6)


/* do variables vary over the periods? ONLY 2001 - 2006 */

egen byte pv = diff(p1 p2 p3 p4 p5 p6)
egen byte eqv = diff(eq1 eq2 eq3 eq4 eq5 eq6)
egen byte emv = diff(em1 em2 em3 em4 em5 em6)
egen byte marlv = diff(marl1 marl2 marl3 marl4 marl5 marl6)
egen byte unmlv = diff(unml1 unml2 unml3 unml4 unml5 unml6)
egen byte lwov = diff(lwo1 lwo2 lwo3 lwo4 lwo5 lwo6)
egen byte disv = diff(dis1 dis2 dis3 dis4 dis5 dis6)
egen byte abvv = diff(abv1 abv2 abv3 abv4 abv5 abv6)
egen byte univ = diff(uni1 uni2 uni3 uni4 uni5 uni6)
egen byte educv = diff(educ1 educ2 educ3 educ4 educ5 educ6)               
egen byte educsqv = diff(educsq1 educsq2 educsq3 educsq4 educsq5 educsq6) 
egen byte forv = diff(for1 for2 for3 for4 for5 for6)
egen byte agev = diff(age1 age2 age3 age4 age5 age6)
egen byte age26v = diff(age26t1 age26t2 age26t3 age26t4 age26t5 age26t6)
egen byte age36v = diff(age36t1 age36t2 age36t3 age36t4 age36t5 age36t6)
egen byte age46v = diff(age46t1 age46t2 age46t3 age46t4 age46t5 age46t6)
egen byte age56v = diff(age56t1 age56t2 age56t3 age56t4 age56t5 age56t6)
egen byte alqv = diff(alq1 alq2 alq3 alq4 alq5 alq6)
egen byte lwowv = diff(lwow1 lwow2 lwow3 lwow4 lwow5 lwow6)
egen byte nordv = diff(nord1 nord2 nord3 nord4 nord5 nord6)
egen byte westv = diff(west1 west2 west3 west4 west5 west6)
egen byte middlev = diff(middle1 middle2 middle3 middle4 middle5 middle6)
egen byte southv = diff(south1 south2 south3 south4 south5 south6)
egen byte berlinv = diff(berlin1 berlin2 berlin3 berlin4 berlin5 berlin6)
egen byte eastv = diff(east1 east2 east3 east4 east5 east6)
egen byte ev = diff(e1 e2 e3 e4 e5 e6)
egen byte wv = diff(w1 w2 w3 w4 w5 w6)
egen byte hchv = diff(hch1 hch2 hch3 hch4 hch5 hch6)
egen byte hadev = diff(hade1 hade2 hade3 hade4 hade5 hade6)
egen byte hadnv = diff(hadn1 hadn2 hadn3 hadn4 hadn5 hadn6)


/* save selected sample (wide format) */

sort persnr

label data "statedata2"
save  "${MY_OUT_PATH}statedata2", replace
desc
sum


/* reshape to long format and save; ONLY 2001 - 2005 */

reshape long p@ p05t@ p07t@ pl@ p05lt@ p07lt@ eq@ em@ eml@ marl@ unml@ lwo@ lwol@ dis@ abv@ uni@ educ@ educsq@ for@ age@ agesq@ age26t@ age36t@ age46t@ age56t@ alq@ lwow@ lwow2665@ lwow2655@ nord@ west@ middle@ south@ berlin@ east@ w@ e@ hch@ hade@ hadn@, i(persnr) j(year 1-6)

keep persnr year lweight p0 p05t0 p07t0 em0 lwo0 p p05t p07t pl p05lt p07lt eq em eml marl unml lwo lwol dis abv uni educ educsq for age agesq age26t age36t age46t age56t alq lwow lwow2665 lwow2655 nord west middle south berlin east w e hch hade hadn pa eqa ema marla unmla lwoa disa abva unia educa educsqa fora agea agesqa age26a age36a age46a age56a alqa lwowa norda westa middlea southa berlina easta ea wa hcha hadea hadna


/* generate interactions of initial condition with time-averages */

gen p0ema = p0*ema 
gen p0marla = p0*marla
gen p0unmla = p0*unmla
gen p0lwoa = p0*lwoa 
gen p0disa = p0*disa
gen p0abva = p0*abva
gen p0unia = p0*unia
gen p0educa = p0*educa
gen p0educsqa = p0*educsqa
gen p0fora = p0*fora
gen p0agea = p0*agea
gen p0agesqa = p0*agesqa
gen p0age26a = p0*age26a
gen p0age36a = p0*age36a
gen p0age46a = p0*age46a
gen p0age56a = p0*age56a
gen p0lwowa = p0*lwowa
gen p0norda = p0*norda
gen p0westa = p0*westa
gen p0middlea = p0*middlea
gen p0southa = p0*southa
gen p0berlina = p0*berlina
gen p0easta = p0*easta
gen p0ea = p0*ea
gen p0wa = p0*wa
gen p0hcha = p0*hcha
gen p0hadea = p0*hadea
gen p0hadna = p0*hadna


sort persnr year

label data "statedata2long"
save  "${MY_OUT_PATH}statedata2long", replace
desc
sum


/* end */

log close

